@@ -69,7 +69,7 @@ class Program(object):
         intensity: float = 83,
         intensity_scaler_func: typing.Callable[[int], float] = None,
         units: str = "kg",
-        round_to: float = 2.5,
+        round_to: typing.Union[float, typing.Callable] = 2.5,
         percent_inc_per_week: float = 1.5,
         progression_func: typing.Callable = None,
         reps_to_intensity_func: typing.Callable[[int], float] = None,
@@ -128,7 +128,7 @@ class Program(object):
 
         round_to
             Round the dynamic exercise to the nearest multiple of this
-            parameter. Typically 2.5, 5 or 10.
+            parameter. Typically 2.5, 5 or 10. A callable can alternatively be passed.
             This value can be set globally for the program, or for a specific
             dynamic exercise. If set at the dynamic exercise level, it will
             override the global program value.
@@ -191,7 +191,13 @@ class Program(object):
         assert isinstance(units, str)
         self.units = units
         self.round_to = round_to
-        self.round = functools.partial(round_to_nearest, nearest=round_to)
+
+        # Create a callable
+        if callable(round_to):
+            self.round = round_to
+        else:
+            self.round = functools.partial(round_to_nearest, nearest=round_to)
+
         self.verbose = verbose
 
         # ------ REP SCALERS ------
@@ -331,13 +337,13 @@ class Program(object):
             round_to,
             shift,
         )
-        self.active_day.dynamic_exercises.append(ex)
+        self.active_day.exercises.append(ex)
         ex.day = self.active_day
         return ex
 
     def StaticExercise(self, name, sets_reps="4 x 10"):
         ex = StaticExercise(name, sets_reps)
-        self.active_day.static_exercises.append(ex)
+        self.active_day.exercises.append(ex)
         return ex
 
     def _validate(self):
@@ -485,8 +491,9 @@ or (3) ignore this message. The software will do it's best to remedy this.
                 self._rendered[week][day] = dict()
 
                 # Iterate over all main exercises
-                for dynamic_ex in day.dynamic_exercises:
-                    self._rendered[week][day][dynamic_ex] = dict()
+                for exercise in day.exercises:
+                    if isinstance(exercise, DynamicExercise):
+                        self._rendered[week][day][exercise] = dict()
 
     def _yield_week_day_dynamic(self):
         """A helper function to reduce the number of nested loops.
@@ -502,8 +509,10 @@ or (3) ignore this message. The software will do it's best to remedy this.
             # Iterate over all days
             for day in self.days:
                 # Iterate over all main exercises
-                for dynamic_ex in day.dynamic_exercises:
-                    yield (week, day, dynamic_ex)
+                for exercise in day.exercises:
+                    if not isinstance(exercise, DynamicExercise):
+                        continue
+                    yield (week, day, exercise)
 
     def _yield_exercises(self):
         """A helper function to reduce the number of nested loops.
@@ -516,10 +525,8 @@ or (3) ignore this message. The software will do it's best to remedy this.
 
         """
         for day in self.days:
-            for dynamic_ex in day.dynamic_exercises:
-                yield dynamic_ex
-            for static_ex in day.static_exercises:
-                yield static_ex
+            for exercise in day.exercises:
+                yield exercise
 
     def render(self, validate=True):
         """Render the training program to perform the calculations.
@@ -539,7 +546,7 @@ or (3) ignore this message. The software will do it's best to remedy this.
         # Check that exercise names are unique within each day
         for day in self.days:
             seen_names = set()
-            for exercise in day.dynamic_exercises + day.static_exercises:
+            for exercise in day.exercises:
                 if exercise.name in seen_names:
                     raise ValueError(f"Exercise name not unique: {exercise.name}")
                 else:
@@ -665,17 +672,17 @@ or (3) ignore this message. The software will do it's best to remedy this.
 
             # Iterate over all days
             for day in self.days:
-                output_day = {"name": day.name, "dynamic_exercises": [], "static_exercises": []}
+                output_day = {"name": day.name, "exercises": []}
 
-                # Iterate over all main exercises
-                for dynamic_ex in day.dynamic_exercises:
-                    out = dynamic_ex.serialize()
-                    out.update(self._rendered[week][day][dynamic_ex])
-                    output_day["dynamic_exercises"].append(out)
-
-                for static_ex in day.static_exercises:
-
-                    output_day["static_exercises"].append(static_ex.serialize())
+                for exercise in day.exercises:
+                    if isinstance(exercise, DynamicExercise):
+                        out = exercise.serialize()
+                        out.update(self._rendered[week][day][exercise])
+                        output_day["exercises"].append(out)
+                    elif isinstance(exercise, StaticExercise):
+                        output_day["exercises"].append(exercise.serialize())
+                    else:
+                        raise TypeError(f"Expected exercise, got object: {exercise}")
 
                 # Add daily
                 output_week.append(output_day)
@@ -700,6 +707,15 @@ or (3) ignore this message. The software will do it's best to remedy this.
         env.filters["round2digits"] = round2digits
         env.filters["mean"] = statistics.mean
 
+        def is_static_exercise(arg):
+            return isinstance(arg, StaticExercise)
+
+        def is_dynamic_exercise(arg):
+            return isinstance(arg, DynamicExercise)
+
+        env.filters["is_static_exercise"] = is_static_exercise
+        env.filters["is_dynamic_exercise"] = is_dynamic_exercise
+
         self.jinja2_environment = env
 
     def to_html(self, table_width=5):
@@ -819,28 +835,6 @@ if __name__ == "__main__":
 
     from streprogen import Program
 
-    program = Program(
-        "My first program!",
-        duration=8,
-        units="kg",
-        reps_per_exercise=15,
-        intensity=88,
-        intensity_scaler_func=lambda w: 1,
-        round_to=2.5,
-        percent_inc_per_week=2,
-        verbose=True,
-    )
-
-    with program.Day("Mandag"):
-        program.DynamicExercise("Knebøy", start_weight=100, min_reps=3, max_reps=5)
-
-    # Render the program, then print it
-    program.render()
-    from pprint import pprint
-
-    # pprint(program.to_dict())
-    print(program)
-
     def rep_scaler_func(week, *args):
         return 1
 
@@ -864,13 +858,11 @@ if __name__ == "__main__":
     )
 
     with program.Day("A"):
-        program.DynamicExercise(name="Squat", start_weight=100, min_reps=5, max_reps=5)
         program.StaticExercise("Biceps", "4 x 10")
+        program.DynamicExercise(name="Squat", start_weight=100, min_reps=5, max_reps=5)
 
     program.render()
 
-    from pprint import pprint
-
     # pprint(program.to_dict())
 
-    # print(program)
+    print(program)
